// src/comments-v2-comment-comments.public.ts
import { renameKeysFromRESTResponseToSDKResponse as renameKeysFromRESTResponseToSDKResponse2 } from "@wix/sdk-runtime/rename-all-nested-keys";
import { transformRESTAudioToSDKAudio as transformRESTAudioToSDKAudio2 } from "@wix/sdk-runtime/transformations/audio";
import { transformRESTDocumentToSDKDocument as transformRESTDocumentToSDKDocument2 } from "@wix/sdk-runtime/transformations/document";
import { transformRESTFloatToSDKFloat as transformRESTFloatToSDKFloat2 } from "@wix/sdk-runtime/transformations/float";
import { transformRESTImageToSDKImage as transformRESTImageToSDKImage2 } from "@wix/sdk-runtime/transformations/image";
import { transformRESTTimestampToSDKTimestamp as transformRESTTimestampToSDKTimestamp2 } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths as transformPaths3 } from "@wix/sdk-runtime/transformations/transform-paths";
import { transformRESTVideoV2ToSDKVideoV2 as transformRESTVideoV2ToSDKVideoV22 } from "@wix/sdk-runtime/transformations/video-v2";
import { EventDefinition } from "@wix/sdk-types";

// src/comments-v2-comment-comments.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import { queryBuilder } from "@wix/sdk-runtime/query-builder";
import {
  renameKeysFromSDKRequestToRESTRequest,
  renameKeysFromRESTResponseToSDKResponse
} from "@wix/sdk-runtime/rename-all-nested-keys";

// src/comments-v2-comment-comments.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKFloatToRESTFloat } from "@wix/sdk-runtime/transformations/float";
import { transformRESTFloatToSDKFloat } from "@wix/sdk-runtime/transformations/float";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixCommentsNgV1CommentsNgUrl(opts) {
  const domainToMappings = {
    "www.wixapis.com": [
      {
        srcPath: "/comments/v1/comments",
        destPath: "/v1/comments"
      },
      {
        srcPath: "/comments/v1/bulk/comments",
        destPath: "/v1/bulk/comments"
      }
    ],
    _: [
      {
        srcPath: "/_api/comments-ng/v1",
        destPath: "/v1"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/comments-ng/v1",
        destPath: "/v1"
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/comments-ng/v1",
        destPath: "/v1"
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/comments-ng",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_comments_comments";
function createComment(payload) {
  function __createComment({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "comment.createdDate" },
          { path: "comment.updatedDate" },
          { path: "comment.commentDate" },
          { path: "comment.content.commentDate" },
          { path: "comment.content.richContent.metadata.createdTimestamp" },
          { path: "comment.content.richContent.metadata.updatedTimestamp" },
          { path: "comment.content.attachments.image.urlExpirationDate" },
          { path: "comment.content.attachments.video.urlExpirationDate" },
          {
            path: "comment.content.attachments.video.posters.urlExpirationDate"
          },
          { path: "comment.content.attachments.audio.urlExpirationDate" },
          { path: "comment.content.attachments.document.urlExpirationDate" },
          { path: "comment.draftContent.commentDate" },
          {
            path: "comment.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "comment.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "comment.draftContent.attachments.image.urlExpirationDate" },
          { path: "comment.draftContent.attachments.video.urlExpirationDate" },
          {
            path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
          },
          { path: "comment.draftContent.attachments.audio.urlExpirationDate" },
          {
            path: "comment.draftContent.attachments.document.urlExpirationDate"
          }
        ]
      },
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          {
            path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "comment.content.richContent.nodes.imageData.image.duration"
          },
          { path: "comment.content.richContent.nodes.mapData.mapSettings.lat" },
          { path: "comment.content.richContent.nodes.mapData.mapSettings.lng" },
          {
            path: "comment.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "comment.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "comment.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "comment.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.CreateComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createComment;
}
function getComment(payload) {
  function __getComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "GET",
      methodFqn: "wix.comments.ng.v1.CommentsNg.GetComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getComment;
}
function updateComment(payload) {
  function __updateComment({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "comment.createdDate" },
          { path: "comment.updatedDate" },
          { path: "comment.commentDate" },
          { path: "comment.content.commentDate" },
          { path: "comment.content.richContent.metadata.createdTimestamp" },
          { path: "comment.content.richContent.metadata.updatedTimestamp" },
          { path: "comment.content.attachments.image.urlExpirationDate" },
          { path: "comment.content.attachments.video.urlExpirationDate" },
          {
            path: "comment.content.attachments.video.posters.urlExpirationDate"
          },
          { path: "comment.content.attachments.audio.urlExpirationDate" },
          { path: "comment.content.attachments.document.urlExpirationDate" },
          { path: "comment.draftContent.commentDate" },
          {
            path: "comment.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "comment.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "comment.draftContent.attachments.image.urlExpirationDate" },
          { path: "comment.draftContent.attachments.video.urlExpirationDate" },
          {
            path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
          },
          { path: "comment.draftContent.attachments.audio.urlExpirationDate" },
          {
            path: "comment.draftContent.attachments.document.urlExpirationDate"
          }
        ]
      },
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          {
            path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "comment.content.richContent.nodes.imageData.image.duration"
          },
          { path: "comment.content.richContent.nodes.mapData.mapSettings.lat" },
          { path: "comment.content.richContent.nodes.mapData.mapSettings.lng" },
          {
            path: "comment.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "comment.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "comment.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "comment.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PATCH",
      methodFqn: "wix.comments.ng.v1.CommentsNg.UpdateComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{comment.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateComment;
}
function deleteComment(payload) {
  function __deleteComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "DELETE",
      methodFqn: "wix.comments.ng.v1.CommentsNg.DeleteComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteComment;
}
function moderateDraftContent(payload) {
  function __moderateDraftContent({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.ModerateDraftContent",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/moderate",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __moderateDraftContent;
}
function queryComments(payload) {
  function __queryComments({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.QueryComments",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/query-cursor",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comments.createdDate" },
            { path: "comments.updatedDate" },
            { path: "comments.commentDate" },
            { path: "comments.content.commentDate" },
            {
              path: "comments.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.content.richContent.metadata.updatedTimestamp"
            },
            { path: "comments.content.attachments.image.urlExpirationDate" },
            { path: "comments.content.attachments.video.urlExpirationDate" },
            {
              path: "comments.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comments.content.attachments.audio.urlExpirationDate" },
            {
              path: "comments.content.attachments.document.urlExpirationDate"
            },
            { path: "comments.draftContent.commentDate" },
            {
              path: "comments.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comments.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comments.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __queryComments;
}
function markComment(payload) {
  function __markComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.MarkComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/mark",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __markComment;
}
function unmarkComment(payload) {
  function __unmarkComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.UnmarkComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/unmark",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __unmarkComment;
}
function hideComment(payload) {
  function __hideComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.HideComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/hide",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __hideComment;
}
function publishComment(payload) {
  function __publishComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.PublishComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/publish",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __publishComment;
}
function countComments(payload) {
  function __countComments({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.CountComments",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/count",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __countComments;
}
function listCommentsByResource(payload) {
  function __listCommentsByResource({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "GET",
      methodFqn: "wix.comments.ng.v1.CommentsNg.ListCommentsByResource",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/list-by-resource",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comments.createdDate" },
            { path: "comments.updatedDate" },
            { path: "comments.commentDate" },
            { path: "comments.content.commentDate" },
            {
              path: "comments.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.content.richContent.metadata.updatedTimestamp"
            },
            { path: "comments.content.attachments.image.urlExpirationDate" },
            { path: "comments.content.attachments.video.urlExpirationDate" },
            {
              path: "comments.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comments.content.attachments.audio.urlExpirationDate" },
            {
              path: "comments.content.attachments.document.urlExpirationDate"
            },
            { path: "comments.draftContent.commentDate" },
            {
              path: "comments.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comments.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.document.urlExpirationDate"
            },
            { path: "commentReplies.*.replies.createdDate" },
            { path: "commentReplies.*.replies.updatedDate" },
            { path: "commentReplies.*.replies.commentDate" },
            { path: "commentReplies.*.replies.content.commentDate" },
            {
              path: "commentReplies.*.replies.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "commentReplies.*.replies.content.richContent.metadata.updatedTimestamp"
            },
            {
              path: "commentReplies.*.replies.content.attachments.image.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.video.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.audio.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.document.urlExpirationDate"
            },
            { path: "commentReplies.*.replies.draftContent.commentDate" },
            {
              path: "commentReplies.*.replies.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comments.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __listCommentsByResource;
}
function getCommentThread(payload) {
  function __getCommentThread({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "GET",
      methodFqn: "wix.comments.ng.v1.CommentsNg.GetCommentThread",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/thread",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comments.createdDate" },
            { path: "comments.updatedDate" },
            { path: "comments.commentDate" },
            { path: "comments.content.commentDate" },
            {
              path: "comments.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.content.richContent.metadata.updatedTimestamp"
            },
            { path: "comments.content.attachments.image.urlExpirationDate" },
            { path: "comments.content.attachments.video.urlExpirationDate" },
            {
              path: "comments.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comments.content.attachments.audio.urlExpirationDate" },
            {
              path: "comments.content.attachments.document.urlExpirationDate"
            },
            { path: "comments.draftContent.commentDate" },
            {
              path: "comments.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comments.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.document.urlExpirationDate"
            },
            { path: "commentReplies.*.replies.createdDate" },
            { path: "commentReplies.*.replies.updatedDate" },
            { path: "commentReplies.*.replies.commentDate" },
            { path: "commentReplies.*.replies.content.commentDate" },
            {
              path: "commentReplies.*.replies.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "commentReplies.*.replies.content.richContent.metadata.updatedTimestamp"
            },
            {
              path: "commentReplies.*.replies.content.attachments.image.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.video.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.audio.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.document.urlExpirationDate"
            },
            { path: "commentReplies.*.replies.draftContent.commentDate" },
            {
              path: "commentReplies.*.replies.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comments.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getCommentThread;
}
function bulkPublishComment(payload) {
  function __bulkPublishComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkPublishComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/publish-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkPublishComment;
}
function bulkHideComment(payload) {
  function __bulkHideComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkHideComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/hide-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkHideComment;
}
function bulkDeleteComment(payload) {
  function __bulkDeleteComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkDeleteComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/delete-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkDeleteComment;
}
function bulkModerateDraftContent(payload) {
  function __bulkModerateDraftContent({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkModerateDraftContent",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/moderate-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkModerateDraftContent;
}
function bulkMoveCommentByFilter(payload) {
  function __bulkMoveCommentByFilter({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkMoveCommentByFilter",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/move-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkMoveCommentByFilter;
}

// src/comments-v2-comment-comments.universal.ts
import { transformSDKAudioToRESTAudio } from "@wix/sdk-runtime/transformations/audio";
import { transformRESTAudioToSDKAudio } from "@wix/sdk-runtime/transformations/audio";
import { transformSDKImageToRESTImage } from "@wix/sdk-runtime/transformations/image";
import { transformRESTImageToSDKImage } from "@wix/sdk-runtime/transformations/image";
import { transformSDKVideoV2ToRESTVideoV2 } from "@wix/sdk-runtime/transformations/video-v2";
import { transformRESTVideoV2ToSDKVideoV2 } from "@wix/sdk-runtime/transformations/video-v2";
import { transformSDKDocumentToRESTDocument } from "@wix/sdk-runtime/transformations/document";
import { transformRESTDocumentToSDKDocument } from "@wix/sdk-runtime/transformations/document";
import { transformPaths as transformPaths2 } from "@wix/sdk-runtime/transformations/transform-paths";
var NodeType = /* @__PURE__ */ ((NodeType2) => {
  NodeType2["PARAGRAPH"] = "PARAGRAPH";
  NodeType2["TEXT"] = "TEXT";
  NodeType2["HEADING"] = "HEADING";
  NodeType2["BULLETED_LIST"] = "BULLETED_LIST";
  NodeType2["ORDERED_LIST"] = "ORDERED_LIST";
  NodeType2["LIST_ITEM"] = "LIST_ITEM";
  NodeType2["BLOCKQUOTE"] = "BLOCKQUOTE";
  NodeType2["CODE_BLOCK"] = "CODE_BLOCK";
  NodeType2["VIDEO"] = "VIDEO";
  NodeType2["DIVIDER"] = "DIVIDER";
  NodeType2["FILE"] = "FILE";
  NodeType2["GALLERY"] = "GALLERY";
  NodeType2["GIF"] = "GIF";
  NodeType2["HTML"] = "HTML";
  NodeType2["IMAGE"] = "IMAGE";
  NodeType2["LINK_PREVIEW"] = "LINK_PREVIEW";
  NodeType2["MAP"] = "MAP";
  NodeType2["POLL"] = "POLL";
  NodeType2["APP_EMBED"] = "APP_EMBED";
  NodeType2["BUTTON"] = "BUTTON";
  NodeType2["COLLAPSIBLE_LIST"] = "COLLAPSIBLE_LIST";
  NodeType2["TABLE"] = "TABLE";
  NodeType2["EMBED"] = "EMBED";
  NodeType2["COLLAPSIBLE_ITEM"] = "COLLAPSIBLE_ITEM";
  NodeType2["COLLAPSIBLE_ITEM_TITLE"] = "COLLAPSIBLE_ITEM_TITLE";
  NodeType2["COLLAPSIBLE_ITEM_BODY"] = "COLLAPSIBLE_ITEM_BODY";
  NodeType2["TABLE_CELL"] = "TABLE_CELL";
  NodeType2["TABLE_ROW"] = "TABLE_ROW";
  NodeType2["EXTERNAL"] = "EXTERNAL";
  NodeType2["AUDIO"] = "AUDIO";
  NodeType2["CAPTION"] = "CAPTION";
  NodeType2["LAYOUT"] = "LAYOUT";
  NodeType2["LAYOUT_CELL"] = "LAYOUT_CELL";
  return NodeType2;
})(NodeType || {});
var WidthType = /* @__PURE__ */ ((WidthType2) => {
  WidthType2["CONTENT"] = "CONTENT";
  WidthType2["SMALL"] = "SMALL";
  WidthType2["ORIGINAL"] = "ORIGINAL";
  WidthType2["FULL_WIDTH"] = "FULL_WIDTH";
  return WidthType2;
})(WidthType || {});
var PluginContainerDataAlignment = /* @__PURE__ */ ((PluginContainerDataAlignment2) => {
  PluginContainerDataAlignment2["CENTER"] = "CENTER";
  PluginContainerDataAlignment2["LEFT"] = "LEFT";
  PluginContainerDataAlignment2["RIGHT"] = "RIGHT";
  return PluginContainerDataAlignment2;
})(PluginContainerDataAlignment || {});
var Type = /* @__PURE__ */ ((Type2) => {
  Type2["LINK"] = "LINK";
  Type2["ACTION"] = "ACTION";
  return Type2;
})(Type || {});
var Target = /* @__PURE__ */ ((Target2) => {
  Target2["SELF"] = "SELF";
  Target2["BLANK"] = "BLANK";
  Target2["PARENT"] = "PARENT";
  Target2["TOP"] = "TOP";
  return Target2;
})(Target || {});
var TextAlignment = /* @__PURE__ */ ((TextAlignment2) => {
  TextAlignment2["AUTO"] = "AUTO";
  TextAlignment2["LEFT"] = "LEFT";
  TextAlignment2["RIGHT"] = "RIGHT";
  TextAlignment2["CENTER"] = "CENTER";
  TextAlignment2["JUSTIFY"] = "JUSTIFY";
  return TextAlignment2;
})(TextAlignment || {});
var LineStyle = /* @__PURE__ */ ((LineStyle2) => {
  LineStyle2["SINGLE"] = "SINGLE";
  LineStyle2["DOUBLE"] = "DOUBLE";
  LineStyle2["DASHED"] = "DASHED";
  LineStyle2["DOTTED"] = "DOTTED";
  return LineStyle2;
})(LineStyle || {});
var Width = /* @__PURE__ */ ((Width2) => {
  Width2["LARGE"] = "LARGE";
  Width2["MEDIUM"] = "MEDIUM";
  Width2["SMALL"] = "SMALL";
  return Width2;
})(Width || {});
var Alignment = /* @__PURE__ */ ((Alignment2) => {
  Alignment2["CENTER"] = "CENTER";
  Alignment2["LEFT"] = "LEFT";
  Alignment2["RIGHT"] = "RIGHT";
  return Alignment2;
})(Alignment || {});
var ViewMode = /* @__PURE__ */ ((ViewMode2) => {
  ViewMode2["NONE"] = "NONE";
  ViewMode2["FULL"] = "FULL";
  ViewMode2["MINI"] = "MINI";
  return ViewMode2;
})(ViewMode || {});
var LayoutType = /* @__PURE__ */ ((LayoutType2) => {
  LayoutType2["COLLAGE"] = "COLLAGE";
  LayoutType2["MASONRY"] = "MASONRY";
  LayoutType2["GRID"] = "GRID";
  LayoutType2["THUMBNAIL"] = "THUMBNAIL";
  LayoutType2["SLIDER"] = "SLIDER";
  LayoutType2["SLIDESHOW"] = "SLIDESHOW";
  LayoutType2["PANORAMA"] = "PANORAMA";
  LayoutType2["COLUMN"] = "COLUMN";
  LayoutType2["MAGIC"] = "MAGIC";
  LayoutType2["FULLSIZE"] = "FULLSIZE";
  return LayoutType2;
})(LayoutType || {});
var Orientation = /* @__PURE__ */ ((Orientation2) => {
  Orientation2["ROWS"] = "ROWS";
  Orientation2["COLUMNS"] = "COLUMNS";
  return Orientation2;
})(Orientation || {});
var Crop = /* @__PURE__ */ ((Crop2) => {
  Crop2["FILL"] = "FILL";
  Crop2["FIT"] = "FIT";
  return Crop2;
})(Crop || {});
var ThumbnailsAlignment = /* @__PURE__ */ ((ThumbnailsAlignment2) => {
  ThumbnailsAlignment2["TOP"] = "TOP";
  ThumbnailsAlignment2["RIGHT"] = "RIGHT";
  ThumbnailsAlignment2["BOTTOM"] = "BOTTOM";
  ThumbnailsAlignment2["LEFT"] = "LEFT";
  ThumbnailsAlignment2["NONE"] = "NONE";
  return ThumbnailsAlignment2;
})(ThumbnailsAlignment || {});
var GIFType = /* @__PURE__ */ ((GIFType2) => {
  GIFType2["NORMAL"] = "NORMAL";
  GIFType2["STICKER"] = "STICKER";
  return GIFType2;
})(GIFType || {});
var Source = /* @__PURE__ */ ((Source2) => {
  Source2["HTML"] = "HTML";
  Source2["ADSENSE"] = "ADSENSE";
  return Source2;
})(Source || {});
var Position = /* @__PURE__ */ ((Position2) => {
  Position2["START"] = "START";
  Position2["END"] = "END";
  Position2["TOP"] = "TOP";
  Position2["HIDDEN"] = "HIDDEN";
  return Position2;
})(Position || {});
var MapType = /* @__PURE__ */ ((MapType2) => {
  MapType2["ROADMAP"] = "ROADMAP";
  MapType2["SATELITE"] = "SATELITE";
  MapType2["HYBRID"] = "HYBRID";
  MapType2["TERRAIN"] = "TERRAIN";
  return MapType2;
})(MapType || {});
var ViewRole = /* @__PURE__ */ ((ViewRole2) => {
  ViewRole2["CREATOR"] = "CREATOR";
  ViewRole2["VOTERS"] = "VOTERS";
  ViewRole2["EVERYONE"] = "EVERYONE";
  return ViewRole2;
})(ViewRole || {});
var VoteRole = /* @__PURE__ */ ((VoteRole2) => {
  VoteRole2["SITE_MEMBERS"] = "SITE_MEMBERS";
  VoteRole2["ALL"] = "ALL";
  return VoteRole2;
})(VoteRole || {});
var PollLayoutType = /* @__PURE__ */ ((PollLayoutType2) => {
  PollLayoutType2["LIST"] = "LIST";
  PollLayoutType2["GRID"] = "GRID";
  return PollLayoutType2;
})(PollLayoutType || {});
var PollLayoutDirection = /* @__PURE__ */ ((PollLayoutDirection2) => {
  PollLayoutDirection2["LTR"] = "LTR";
  PollLayoutDirection2["RTL"] = "RTL";
  return PollLayoutDirection2;
})(PollLayoutDirection || {});
var BackgroundType = /* @__PURE__ */ ((BackgroundType2) => {
  BackgroundType2["COLOR"] = "COLOR";
  BackgroundType2["IMAGE"] = "IMAGE";
  BackgroundType2["GRADIENT"] = "GRADIENT";
  return BackgroundType2;
})(BackgroundType || {});
var DecorationType = /* @__PURE__ */ ((DecorationType2) => {
  DecorationType2["BOLD"] = "BOLD";
  DecorationType2["ITALIC"] = "ITALIC";
  DecorationType2["UNDERLINE"] = "UNDERLINE";
  DecorationType2["SPOILER"] = "SPOILER";
  DecorationType2["ANCHOR"] = "ANCHOR";
  DecorationType2["MENTION"] = "MENTION";
  DecorationType2["LINK"] = "LINK";
  DecorationType2["COLOR"] = "COLOR";
  DecorationType2["FONT_SIZE"] = "FONT_SIZE";
  DecorationType2["EXTERNAL"] = "EXTERNAL";
  DecorationType2["STRIKETHROUGH"] = "STRIKETHROUGH";
  DecorationType2["SUPERSCRIPT"] = "SUPERSCRIPT";
  DecorationType2["SUBSCRIPT"] = "SUBSCRIPT";
  return DecorationType2;
})(DecorationType || {});
var FontType = /* @__PURE__ */ ((FontType2) => {
  FontType2["PX"] = "PX";
  FontType2["EM"] = "EM";
  return FontType2;
})(FontType || {});
var AppType = /* @__PURE__ */ ((AppType2) => {
  AppType2["PRODUCT"] = "PRODUCT";
  AppType2["EVENT"] = "EVENT";
  AppType2["BOOKING"] = "BOOKING";
  return AppType2;
})(AppType || {});
var InitialExpandedItems = /* @__PURE__ */ ((InitialExpandedItems2) => {
  InitialExpandedItems2["FIRST"] = "FIRST";
  InitialExpandedItems2["ALL"] = "ALL";
  InitialExpandedItems2["NONE"] = "NONE";
  return InitialExpandedItems2;
})(InitialExpandedItems || {});
var Direction = /* @__PURE__ */ ((Direction2) => {
  Direction2["LTR"] = "LTR";
  Direction2["RTL"] = "RTL";
  return Direction2;
})(Direction || {});
var VerticalAlignment = /* @__PURE__ */ ((VerticalAlignment2) => {
  VerticalAlignment2["TOP"] = "TOP";
  VerticalAlignment2["MIDDLE"] = "MIDDLE";
  VerticalAlignment2["BOTTOM"] = "BOTTOM";
  return VerticalAlignment2;
})(VerticalAlignment || {});
var NullValue = /* @__PURE__ */ ((NullValue2) => {
  NullValue2["NULL_VALUE"] = "NULL_VALUE";
  return NullValue2;
})(NullValue || {});
var Status = /* @__PURE__ */ ((Status2) => {
  Status2["UNKNOWN"] = "UNKNOWN";
  Status2["PUBLISHED"] = "PUBLISHED";
  Status2["DELETED"] = "DELETED";
  Status2["PENDING"] = "PENDING";
  Status2["HIDDEN"] = "HIDDEN";
  return Status2;
})(Status || {});
var VersioningMode = /* @__PURE__ */ ((VersioningMode2) => {
  VersioningMode2["DEFAULT"] = "DEFAULT";
  VersioningMode2["GREATER_THAN"] = "GREATER_THAN";
  VersioningMode2["GREATER_OR_EQUAL"] = "GREATER_OR_EQUAL";
  return VersioningMode2;
})(VersioningMode || {});
var Action = /* @__PURE__ */ ((Action2) => {
  Action2["UNKNOWN"] = "UNKNOWN";
  Action2["APPROVE"] = "APPROVE";
  Action2["REJECT"] = "REJECT";
  return Action2;
})(Action || {});
var SortOrder = /* @__PURE__ */ ((SortOrder2) => {
  SortOrder2["ASC"] = "ASC";
  SortOrder2["DESC"] = "DESC";
  return SortOrder2;
})(SortOrder || {});
var Order = /* @__PURE__ */ ((Order2) => {
  Order2["UNKNOWN_ORDER"] = "UNKNOWN_ORDER";
  Order2["OLDEST_FIRST"] = "OLDEST_FIRST";
  Order2["NEWEST_FIRST"] = "NEWEST_FIRST";
  Order2["REACTION_COUNT"] = "REACTION_COUNT";
  Order2["NET_VOTE_COUNT"] = "NET_VOTE_COUNT";
  Order2["RATING"] = "RATING";
  Order2["NET_VOTE_COUNT_ASC"] = "NET_VOTE_COUNT_ASC";
  Order2["RATING_ASC"] = "RATING_ASC";
  return Order2;
})(Order || {});
var ReplySortOrder = /* @__PURE__ */ ((ReplySortOrder2) => {
  ReplySortOrder2["UNKNOWN_ORDER"] = "UNKNOWN_ORDER";
  ReplySortOrder2["OLDEST_FIRST"] = "OLDEST_FIRST";
  ReplySortOrder2["NEWEST_FIRST"] = "NEWEST_FIRST";
  ReplySortOrder2["REACTION_COUNT"] = "REACTION_COUNT";
  return ReplySortOrder2;
})(ReplySortOrder || {});
var WebhookIdentityType = /* @__PURE__ */ ((WebhookIdentityType2) => {
  WebhookIdentityType2["UNKNOWN"] = "UNKNOWN";
  WebhookIdentityType2["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
  WebhookIdentityType2["MEMBER"] = "MEMBER";
  WebhookIdentityType2["WIX_USER"] = "WIX_USER";
  WebhookIdentityType2["APP"] = "APP";
  return WebhookIdentityType2;
})(WebhookIdentityType || {});
async function createComment2(comment) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = transformPaths2(
    renameKeysFromSDKRequestToRESTRequest({ comment }, [
      "comment.content.richContent",
      "comment.draftContent.richContent"
    ]),
    [
      {
        transformFn: transformSDKImageToRESTImage,
        paths: [
          { path: "comment.content.attachments.image" },
          { path: "comment.draftContent.attachments.image" }
        ]
      },
      {
        transformFn: transformSDKVideoV2ToRESTVideoV2,
        paths: [
          { path: "comment.content.attachments.video" },
          { path: "comment.draftContent.attachments.video" }
        ]
      },
      {
        transformFn: transformSDKAudioToRESTAudio,
        paths: [
          { path: "comment.content.attachments.audio" },
          { path: "comment.draftContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformSDKDocumentToRESTDocument,
        paths: [
          { path: "comment.content.attachments.document" },
          { path: "comment.draftContent.attachments.document" }
        ]
      }
    ]
  );
  const reqOpts = createComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comment.content.attachments.image" },
            { path: "comment.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comment.content.attachments.video" },
            { path: "comment.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comment.content.attachments.audio" },
            { path: "comment.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comment.content.attachments.document" },
            { path: "comment.draftContent.attachments.document" }
          ]
        }
      ]),
      ["comment.content.richContent", "comment.draftContent.richContent"]
    )?.comment;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { comment: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["comment"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getComment2(commentId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { commentId },
    []
  );
  const reqOpts = getComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comment.content.attachments.image" },
            { path: "comment.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comment.content.attachments.video" },
            { path: "comment.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comment.content.attachments.audio" },
            { path: "comment.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comment.content.attachments.document" },
            { path: "comment.draftContent.attachments.document" }
          ]
        }
      ]),
      ["comment.content.richContent", "comment.draftContent.richContent"]
    )?.comment;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { commentId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["commentId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function updateComment2(_id, comment) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = transformPaths2(
    renameKeysFromSDKRequestToRESTRequest(
      { comment: { ...comment, id: _id } },
      ["comment.content.richContent", "comment.draftContent.richContent"]
    ),
    [
      {
        transformFn: transformSDKImageToRESTImage,
        paths: [
          { path: "comment.content.attachments.image" },
          { path: "comment.draftContent.attachments.image" }
        ]
      },
      {
        transformFn: transformSDKVideoV2ToRESTVideoV2,
        paths: [
          { path: "comment.content.attachments.video" },
          { path: "comment.draftContent.attachments.video" }
        ]
      },
      {
        transformFn: transformSDKAudioToRESTAudio,
        paths: [
          { path: "comment.content.attachments.audio" },
          { path: "comment.draftContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformSDKDocumentToRESTDocument,
        paths: [
          { path: "comment.content.attachments.document" },
          { path: "comment.draftContent.attachments.document" }
        ]
      }
    ]
  );
  const reqOpts = updateComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comment.content.attachments.image" },
            { path: "comment.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comment.content.attachments.video" },
            { path: "comment.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comment.content.attachments.audio" },
            { path: "comment.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comment.content.attachments.document" },
            { path: "comment.draftContent.attachments.document" }
          ]
        }
      ]),
      ["comment.content.richContent", "comment.draftContent.richContent"]
    )?.comment;
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: { comment: "$[1]" },
        explicitPathsToArguments: { "comment.id": "$[0]" },
        singleArgumentUnchanged: false
      },
      ["_id", "comment"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function deleteComment2(commentId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { commentId },
    []
  );
  const reqOpts = deleteComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { commentId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["commentId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function moderateDraftContent2(commentId, revision, options) {
  const { httpClient, sideEffects } = arguments[3];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    {
      commentId,
      revision,
      draftContentAction: options?.draftContentAction
    },
    []
  );
  const reqOpts = moderateDraftContent(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comment.content.attachments.image" },
            { path: "comment.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comment.content.attachments.video" },
            { path: "comment.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comment.content.attachments.audio" },
            { path: "comment.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comment.content.attachments.document" },
            { path: "comment.draftContent.attachments.document" }
          ]
        }
      ]),
      ["comment.content.richContent", "comment.draftContent.richContent"]
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          commentId: "$[0]",
          revision: "$[1]",
          draftContentAction: "$[2].draftContentAction"
        },
        singleArgumentUnchanged: false
      },
      ["commentId", "revision", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
function queryComments2(appId) {
  const { httpClient, sideEffects } = arguments[1];
  return queryBuilder({
    func: async (payload) => {
      const reqOpts = queryComments(payload);
      sideEffects?.onSiteCall?.();
      try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return result;
      } catch (err) {
        sideEffects?.onError?.(err);
        throw err;
      }
    },
    requestTransformer: (query) => {
      const args = [query, appId, {}];
      return renameKeysFromSDKRequestToRESTRequest(
        { appId: args?.[1], ...args?.[2], query: args?.[0] },
        []
      );
    },
    responseTransformer: ({ data }) => {
      const transformedData = renameKeysFromRESTResponseToSDKResponse(
        transformPaths2(data, [
          {
            transformFn: transformRESTImageToSDKImage,
            paths: [
              { path: "comments.content.attachments.image" },
              { path: "comments.draftContent.attachments.image" }
            ]
          },
          {
            transformFn: transformRESTVideoV2ToSDKVideoV2,
            paths: [
              { path: "comments.content.attachments.video" },
              { path: "comments.draftContent.attachments.video" }
            ]
          },
          {
            transformFn: transformRESTAudioToSDKAudio,
            paths: [
              { path: "comments.content.attachments.audio" },
              { path: "comments.draftContent.attachments.audio" }
            ]
          },
          {
            transformFn: transformRESTDocumentToSDKDocument,
            paths: [
              { path: "comments.content.attachments.document" },
              { path: "comments.draftContent.attachments.document" }
            ]
          }
        ]),
        ["comments.content.richContent", "comments.draftContent.richContent"]
      );
      return {
        items: transformedData?.comments,
        pagingMetadata: transformedData?.pagingMetadata
      };
    },
    errorTransformer: (err) => {
      const transformedError = sdkTransformError(err, {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { appId: "$[1]", query: "$[0]" },
        singleArgumentUnchanged: false
      });
      throw transformedError;
    },
    pagingMethod: "CURSOR",
    transformationPaths: {}
  });
}
async function markComment2(commentId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { commentId },
    []
  );
  const reqOpts = markComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comment.content.attachments.image" },
            { path: "comment.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comment.content.attachments.video" },
            { path: "comment.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comment.content.attachments.audio" },
            { path: "comment.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comment.content.attachments.document" },
            { path: "comment.draftContent.attachments.document" }
          ]
        }
      ]),
      ["comment.content.richContent", "comment.draftContent.richContent"]
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { commentId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["commentId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function unmarkComment2(commentId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { commentId },
    []
  );
  const reqOpts = unmarkComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comment.content.attachments.image" },
            { path: "comment.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comment.content.attachments.video" },
            { path: "comment.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comment.content.attachments.audio" },
            { path: "comment.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comment.content.attachments.document" },
            { path: "comment.draftContent.attachments.document" }
          ]
        }
      ]),
      ["comment.content.richContent", "comment.draftContent.richContent"]
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { commentId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["commentId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function hideComment2(commentId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { commentId },
    []
  );
  const reqOpts = hideComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comment.content.attachments.image" },
            { path: "comment.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comment.content.attachments.video" },
            { path: "comment.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comment.content.attachments.audio" },
            { path: "comment.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comment.content.attachments.document" },
            { path: "comment.draftContent.attachments.document" }
          ]
        }
      ]),
      ["comment.content.richContent", "comment.draftContent.richContent"]
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { commentId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["commentId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function publishComment2(commentId) {
  const { httpClient, sideEffects } = arguments[1];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { commentId },
    []
  );
  const reqOpts = publishComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comment.content.attachments.image" },
            { path: "comment.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comment.content.attachments.video" },
            { path: "comment.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comment.content.attachments.audio" },
            { path: "comment.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comment.content.attachments.document" },
            { path: "comment.draftContent.attachments.document" }
          ]
        }
      ]),
      ["comment.content.richContent", "comment.draftContent.richContent"]
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { commentId: "$[0]" },
        singleArgumentUnchanged: false
      },
      ["commentId"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function countComments2(appId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { appId, filter: options?.filter },
    []
  );
  const reqOpts = countComments(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data, []);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { appId: "$[0]", filter: "$[1].filter" },
        singleArgumentUnchanged: false
      },
      ["appId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function listCommentsByResource2(appId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    {
      appId,
      contextId: options?.contextId,
      contextType: options?.contextType,
      resourceId: options?.resourceId,
      commentSort: options?.commentSort,
      replySort: options?.replySort,
      cursorPaging: options?.cursorPaging
    },
    []
  );
  const reqOpts = listCommentsByResource(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comments.content.attachments.image" },
            { path: "comments.draftContent.attachments.image" },
            { path: "commentReplies.*.replies.content.attachments.image" },
            { path: "commentReplies.*.replies.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comments.content.attachments.video" },
            { path: "comments.draftContent.attachments.video" },
            { path: "commentReplies.*.replies.content.attachments.video" },
            { path: "commentReplies.*.replies.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comments.content.attachments.audio" },
            { path: "comments.draftContent.attachments.audio" },
            { path: "commentReplies.*.replies.content.attachments.audio" },
            { path: "commentReplies.*.replies.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comments.content.attachments.document" },
            { path: "comments.draftContent.attachments.document" },
            { path: "commentReplies.*.replies.content.attachments.document" },
            {
              path: "commentReplies.*.replies.draftContent.attachments.document"
            }
          ]
        }
      ]),
      ["comments.content.richContent", "comments.draftContent.richContent"]
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          appId: "$[0]",
          contextId: "$[1].contextId",
          contextType: "$[1].contextType",
          resourceId: "$[1].resourceId",
          commentSort: "$[1].commentSort",
          replySort: "$[1].replySort",
          cursorPaging: "$[1].cursorPaging"
        },
        singleArgumentUnchanged: false
      },
      ["appId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function getCommentThread2(commentId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    {
      commentId,
      appId: options?.appId,
      commentSort: options?.commentSort,
      replySort: options?.replySort
    },
    []
  );
  const reqOpts = getCommentThread(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(
      transformPaths2(result.data, [
        {
          transformFn: transformRESTImageToSDKImage,
          paths: [
            { path: "comments.content.attachments.image" },
            { path: "comments.draftContent.attachments.image" },
            { path: "commentReplies.*.replies.content.attachments.image" },
            { path: "commentReplies.*.replies.draftContent.attachments.image" }
          ]
        },
        {
          transformFn: transformRESTVideoV2ToSDKVideoV2,
          paths: [
            { path: "comments.content.attachments.video" },
            { path: "comments.draftContent.attachments.video" },
            { path: "commentReplies.*.replies.content.attachments.video" },
            { path: "commentReplies.*.replies.draftContent.attachments.video" }
          ]
        },
        {
          transformFn: transformRESTAudioToSDKAudio,
          paths: [
            { path: "comments.content.attachments.audio" },
            { path: "comments.draftContent.attachments.audio" },
            { path: "commentReplies.*.replies.content.attachments.audio" },
            { path: "commentReplies.*.replies.draftContent.attachments.audio" }
          ]
        },
        {
          transformFn: transformRESTDocumentToSDKDocument,
          paths: [
            { path: "comments.content.attachments.document" },
            { path: "comments.draftContent.attachments.document" },
            { path: "commentReplies.*.replies.content.attachments.document" },
            {
              path: "commentReplies.*.replies.draftContent.attachments.document"
            }
          ]
        }
      ]),
      ["comments.content.richContent", "comments.draftContent.richContent"]
    );
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          commentId: "$[0]",
          appId: "$[1].appId",
          commentSort: "$[1].commentSort",
          replySort: "$[1].replySort"
        },
        singleArgumentUnchanged: false
      },
      ["commentId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkPublishComment2(appId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { appId, filter: options?.filter },
    []
  );
  const reqOpts = bulkPublishComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data, []);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { appId: "$[0]", filter: "$[1].filter" },
        singleArgumentUnchanged: false
      },
      ["appId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkHideComment2(appId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { appId, filter: options?.filter },
    []
  );
  const reqOpts = bulkHideComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data, []);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { appId: "$[0]", filter: "$[1].filter" },
        singleArgumentUnchanged: false
      },
      ["appId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkDeleteComment2(appId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    { appId, filter: options?.filter },
    []
  );
  const reqOpts = bulkDeleteComment(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data, []);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: { appId: "$[0]", filter: "$[1].filter" },
        singleArgumentUnchanged: false
      },
      ["appId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkModerateDraftContent2(appId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    {
      appId,
      filter: options?.filter,
      draftContentAction: options?.draftContentAction
    },
    []
  );
  const reqOpts = bulkModerateDraftContent(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data, []);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          appId: "$[0]",
          filter: "$[1].filter",
          draftContentAction: "$[1].draftContentAction"
        },
        singleArgumentUnchanged: false
      },
      ["appId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
async function bulkMoveCommentByFilter2(appId, options) {
  const { httpClient, sideEffects } = arguments[2];
  const payload = renameKeysFromSDKRequestToRESTRequest(
    {
      appId,
      filter: options?.filter,
      destination: options?.destination
    },
    []
  );
  const reqOpts = bulkMoveCommentByFilter(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
    return renameKeysFromRESTResponseToSDKResponse(result.data, []);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          appId: "$[0]",
          filter: "$[1].filter",
          destination: "$[1].destination"
        },
        singleArgumentUnchanged: false
      },
      ["appId", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}

// src/comments-v2-comment-comments.public.ts
function createComment3(httpClient) {
  return (comment) => createComment2(
    comment,
    // @ts-ignore
    { httpClient }
  );
}
function getComment3(httpClient) {
  return (commentId) => getComment2(
    commentId,
    // @ts-ignore
    { httpClient }
  );
}
function updateComment3(httpClient) {
  return (_id, comment) => updateComment2(
    _id,
    comment,
    // @ts-ignore
    { httpClient }
  );
}
function deleteComment3(httpClient) {
  return (commentId) => deleteComment2(
    commentId,
    // @ts-ignore
    { httpClient }
  );
}
function moderateDraftContent3(httpClient) {
  return (commentId, revision, options) => moderateDraftContent2(
    commentId,
    revision,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function queryComments3(httpClient) {
  return (appId) => queryComments2(
    appId,
    // @ts-ignore
    { httpClient }
  );
}
function markComment3(httpClient) {
  return (commentId) => markComment2(
    commentId,
    // @ts-ignore
    { httpClient }
  );
}
function unmarkComment3(httpClient) {
  return (commentId) => unmarkComment2(
    commentId,
    // @ts-ignore
    { httpClient }
  );
}
function hideComment3(httpClient) {
  return (commentId) => hideComment2(
    commentId,
    // @ts-ignore
    { httpClient }
  );
}
function publishComment3(httpClient) {
  return (commentId) => publishComment2(
    commentId,
    // @ts-ignore
    { httpClient }
  );
}
function countComments3(httpClient) {
  return (appId, options) => countComments2(
    appId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function listCommentsByResource3(httpClient) {
  return (appId, options) => listCommentsByResource2(
    appId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function getCommentThread3(httpClient) {
  return (commentId, options) => getCommentThread2(
    commentId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function bulkPublishComment3(httpClient) {
  return (appId, options) => bulkPublishComment2(
    appId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function bulkHideComment3(httpClient) {
  return (appId, options) => bulkHideComment2(
    appId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function bulkDeleteComment3(httpClient) {
  return (appId, options) => bulkDeleteComment2(
    appId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function bulkModerateDraftContent3(httpClient) {
  return (appId, options) => bulkModerateDraftContent2(
    appId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
function bulkMoveCommentByFilter3(httpClient) {
  return (appId, options) => bulkMoveCommentByFilter2(
    appId,
    options,
    // @ts-ignore
    { httpClient }
  );
}
var onCommentContentChanged = EventDefinition(
  "wix.comments.v2.comment_comment_content_changed",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "data.previousContent.commentDate" },
          {
            path: "data.previousContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.previousContent.richContent.metadata.updatedTimestamp"
          },
          { path: "data.currentContent.commentDate" },
          {
            path: "data.currentContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.currentContent.richContent.metadata.updatedTimestamp"
          },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          {
            path: "data.previousContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.previousContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.previousContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.previousContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.previousContent.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.currentContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.currentContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.currentContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.currentContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [
          { path: "data.previousContent.attachments.image" },
          { path: "data.currentContent.attachments.image" }
        ]
      },
      {
        transformFn: transformRESTVideoV2ToSDKVideoV22,
        paths: [
          { path: "data.previousContent.attachments.video" },
          { path: "data.currentContent.attachments.video" }
        ]
      },
      {
        transformFn: transformRESTAudioToSDKAudio2,
        paths: [
          { path: "data.previousContent.attachments.audio" },
          { path: "data.currentContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [
          { path: "data.previousContent.attachments.document" },
          { path: "data.currentContent.attachments.document" }
        ]
      }
    ])
  )
)();
var onCommentHidden = EventDefinition(
  "wix.comments.v2.comment_comment_hidden",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "data.comment.createdDate" },
          { path: "data.comment.updatedDate" },
          { path: "data.comment.commentDate" },
          { path: "data.comment.content.commentDate" },
          {
            path: "data.comment.content.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.content.richContent.metadata.updatedTimestamp"
          },
          { path: "data.comment.draftContent.commentDate" },
          {
            path: "data.comment.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.content.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [
          { path: "data.comment.content.attachments.image" },
          { path: "data.comment.draftContent.attachments.image" }
        ]
      },
      {
        transformFn: transformRESTVideoV2ToSDKVideoV22,
        paths: [
          { path: "data.comment.content.attachments.video" },
          { path: "data.comment.draftContent.attachments.video" }
        ]
      },
      {
        transformFn: transformRESTAudioToSDKAudio2,
        paths: [
          { path: "data.comment.content.attachments.audio" },
          { path: "data.comment.draftContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [
          { path: "data.comment.content.attachments.document" },
          { path: "data.comment.draftContent.attachments.document" }
        ]
      }
    ])
  )
)();
var onCommentMarked = EventDefinition(
  "wix.comments.v2.comment_comment_marked",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "data.comment.createdDate" },
          { path: "data.comment.updatedDate" },
          { path: "data.comment.commentDate" },
          { path: "data.comment.content.commentDate" },
          {
            path: "data.comment.content.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.content.richContent.metadata.updatedTimestamp"
          },
          { path: "data.comment.draftContent.commentDate" },
          {
            path: "data.comment.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.content.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [
          { path: "data.comment.content.attachments.image" },
          { path: "data.comment.draftContent.attachments.image" }
        ]
      },
      {
        transformFn: transformRESTVideoV2ToSDKVideoV22,
        paths: [
          { path: "data.comment.content.attachments.video" },
          { path: "data.comment.draftContent.attachments.video" }
        ]
      },
      {
        transformFn: transformRESTAudioToSDKAudio2,
        paths: [
          { path: "data.comment.content.attachments.audio" },
          { path: "data.comment.draftContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [
          { path: "data.comment.content.attachments.document" },
          { path: "data.comment.draftContent.attachments.document" }
        ]
      }
    ])
  )
)();
var onCommentMoved = EventDefinition(
  "wix.comments.v2.comment_comment_moved",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "data.comment.createdDate" },
          { path: "data.comment.updatedDate" },
          { path: "data.comment.commentDate" },
          { path: "data.comment.content.commentDate" },
          {
            path: "data.comment.content.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.content.richContent.metadata.updatedTimestamp"
          },
          { path: "data.comment.draftContent.commentDate" },
          {
            path: "data.comment.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.content.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [
          { path: "data.comment.content.attachments.image" },
          { path: "data.comment.draftContent.attachments.image" }
        ]
      },
      {
        transformFn: transformRESTVideoV2ToSDKVideoV22,
        paths: [
          { path: "data.comment.content.attachments.video" },
          { path: "data.comment.draftContent.attachments.video" }
        ]
      },
      {
        transformFn: transformRESTAudioToSDKAudio2,
        paths: [
          { path: "data.comment.content.attachments.audio" },
          { path: "data.comment.draftContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [
          { path: "data.comment.content.attachments.document" },
          { path: "data.comment.draftContent.attachments.document" }
        ]
      }
    ])
  )
)();
var onCommentPublished = EventDefinition(
  "wix.comments.v2.comment_comment_published",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "data.comment.createdDate" },
          { path: "data.comment.updatedDate" },
          { path: "data.comment.commentDate" },
          { path: "data.comment.content.commentDate" },
          {
            path: "data.comment.content.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.content.richContent.metadata.updatedTimestamp"
          },
          { path: "data.comment.draftContent.commentDate" },
          {
            path: "data.comment.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.content.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [
          { path: "data.comment.content.attachments.image" },
          { path: "data.comment.draftContent.attachments.image" }
        ]
      },
      {
        transformFn: transformRESTVideoV2ToSDKVideoV22,
        paths: [
          { path: "data.comment.content.attachments.video" },
          { path: "data.comment.draftContent.attachments.video" }
        ]
      },
      {
        transformFn: transformRESTAudioToSDKAudio2,
        paths: [
          { path: "data.comment.content.attachments.audio" },
          { path: "data.comment.draftContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [
          { path: "data.comment.content.attachments.document" },
          { path: "data.comment.draftContent.attachments.document" }
        ]
      }
    ])
  )
)();
var onCommentUnmarked = EventDefinition(
  "wix.comments.v2.comment_comment_unmarked",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "data.comment.createdDate" },
          { path: "data.comment.updatedDate" },
          { path: "data.comment.commentDate" },
          { path: "data.comment.content.commentDate" },
          {
            path: "data.comment.content.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.content.richContent.metadata.updatedTimestamp"
          },
          { path: "data.comment.draftContent.commentDate" },
          {
            path: "data.comment.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "data.comment.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.content.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.content.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "data.comment.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [
          { path: "data.comment.content.attachments.image" },
          { path: "data.comment.draftContent.attachments.image" }
        ]
      },
      {
        transformFn: transformRESTVideoV2ToSDKVideoV22,
        paths: [
          { path: "data.comment.content.attachments.video" },
          { path: "data.comment.draftContent.attachments.video" }
        ]
      },
      {
        transformFn: transformRESTAudioToSDKAudio2,
        paths: [
          { path: "data.comment.content.attachments.audio" },
          { path: "data.comment.draftContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [
          { path: "data.comment.content.attachments.document" },
          { path: "data.comment.draftContent.attachments.document" }
        ]
      }
    ])
  )
)();
var onCommentCreated = EventDefinition(
  "wix.comments.v2.comment_created",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "entity.createdDate" },
          { path: "entity.updatedDate" },
          { path: "entity.commentDate" },
          { path: "entity.content.commentDate" },
          { path: "entity.content.richContent.metadata.createdTimestamp" },
          { path: "entity.content.richContent.metadata.updatedTimestamp" },
          { path: "entity.draftContent.commentDate" },
          {
            path: "entity.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "entity.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          {
            path: "entity.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "entity.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "entity.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "entity.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "entity.content.richContent.nodes.imageData.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "entity.content.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "entity.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "entity.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "entity.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "entity.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "entity.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "entity.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "entity.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [
          { path: "entity.content.attachments.image" },
          { path: "entity.draftContent.attachments.image" }
        ]
      },
      {
        transformFn: transformRESTVideoV2ToSDKVideoV22,
        paths: [
          { path: "entity.content.attachments.video" },
          { path: "entity.draftContent.attachments.video" }
        ]
      },
      {
        transformFn: transformRESTAudioToSDKAudio2,
        paths: [
          { path: "entity.content.attachments.audio" },
          { path: "entity.draftContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [
          { path: "entity.content.attachments.document" },
          { path: "entity.draftContent.attachments.document" }
        ]
      }
    ])
  )
)();
var onCommentResourceCommentCountChanged = EventDefinition(
  "wix.comments.v2.comment_resource_comment_count_changed",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [{ path: "metadata.eventTime" }]
      }
    ])
  )
)();
var onCommentUpdated = EventDefinition(
  "wix.comments.v2.comment_updated",
  true,
  (event) => renameKeysFromRESTResponseToSDKResponse2(
    transformPaths3(event, [
      {
        transformFn: transformRESTTimestampToSDKTimestamp2,
        paths: [
          { path: "entity.createdDate" },
          { path: "entity.updatedDate" },
          { path: "entity.commentDate" },
          { path: "entity.content.commentDate" },
          { path: "entity.content.richContent.metadata.createdTimestamp" },
          { path: "entity.content.richContent.metadata.updatedTimestamp" },
          { path: "entity.draftContent.commentDate" },
          {
            path: "entity.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "entity.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "metadata.eventTime" }
        ]
      },
      {
        transformFn: transformRESTFloatToSDKFloat2,
        paths: [
          {
            path: "entity.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "entity.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "entity.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "entity.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "entity.content.richContent.nodes.imageData.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "entity.content.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "entity.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "entity.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "entity.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "entity.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "entity.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "entity.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "entity.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "entity.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "entity.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      },
      {
        transformFn: transformRESTImageToSDKImage2,
        paths: [
          { path: "entity.content.attachments.image" },
          { path: "entity.draftContent.attachments.image" }
        ]
      },
      {
        transformFn: transformRESTVideoV2ToSDKVideoV22,
        paths: [
          { path: "entity.content.attachments.video" },
          { path: "entity.draftContent.attachments.video" }
        ]
      },
      {
        transformFn: transformRESTAudioToSDKAudio2,
        paths: [
          { path: "entity.content.attachments.audio" },
          { path: "entity.draftContent.attachments.audio" }
        ]
      },
      {
        transformFn: transformRESTDocumentToSDKDocument2,
        paths: [
          { path: "entity.content.attachments.document" },
          { path: "entity.draftContent.attachments.document" }
        ]
      }
    ])
  )
)();

// src/comments-v2-comment-comments.context.ts
import { createRESTModule } from "@wix/sdk-runtime/rest-modules";
import { createEventModule } from "@wix/sdk-runtime/event-definition-modules";
var createComment4 = /* @__PURE__ */ createRESTModule(createComment3);
var getComment4 = /* @__PURE__ */ createRESTModule(getComment3);
var updateComment4 = /* @__PURE__ */ createRESTModule(updateComment3);
var deleteComment4 = /* @__PURE__ */ createRESTModule(deleteComment3);
var moderateDraftContent4 = /* @__PURE__ */ createRESTModule(moderateDraftContent3);
var queryComments4 = /* @__PURE__ */ createRESTModule(queryComments3);
var markComment4 = /* @__PURE__ */ createRESTModule(markComment3);
var unmarkComment4 = /* @__PURE__ */ createRESTModule(unmarkComment3);
var hideComment4 = /* @__PURE__ */ createRESTModule(hideComment3);
var publishComment4 = /* @__PURE__ */ createRESTModule(publishComment3);
var countComments4 = /* @__PURE__ */ createRESTModule(countComments3);
var listCommentsByResource4 = /* @__PURE__ */ createRESTModule(listCommentsByResource3);
var getCommentThread4 = /* @__PURE__ */ createRESTModule(getCommentThread3);
var bulkPublishComment4 = /* @__PURE__ */ createRESTModule(bulkPublishComment3);
var bulkHideComment4 = /* @__PURE__ */ createRESTModule(bulkHideComment3);
var bulkDeleteComment4 = /* @__PURE__ */ createRESTModule(bulkDeleteComment3);
var bulkModerateDraftContent4 = /* @__PURE__ */ createRESTModule(bulkModerateDraftContent3);
var bulkMoveCommentByFilter4 = /* @__PURE__ */ createRESTModule(bulkMoveCommentByFilter3);
var onCommentContentChanged2 = createEventModule(onCommentContentChanged);
var onCommentHidden2 = createEventModule(onCommentHidden);
var onCommentMarked2 = createEventModule(onCommentMarked);
var onCommentMoved2 = createEventModule(onCommentMoved);
var onCommentPublished2 = createEventModule(onCommentPublished);
var onCommentUnmarked2 = createEventModule(onCommentUnmarked);
var onCommentCreated2 = createEventModule(onCommentCreated);
var onCommentResourceCommentCountChanged2 = createEventModule(onCommentResourceCommentCountChanged);
var onCommentUpdated2 = createEventModule(onCommentUpdated);
export {
  Action,
  Alignment,
  AppType,
  BackgroundType,
  Crop,
  DecorationType,
  Direction,
  FontType,
  GIFType,
  InitialExpandedItems,
  LayoutType,
  LineStyle,
  MapType,
  NodeType,
  NullValue,
  Order,
  Orientation,
  PluginContainerDataAlignment,
  PollLayoutDirection,
  PollLayoutType,
  Position,
  ReplySortOrder,
  SortOrder,
  Source,
  Status,
  Target,
  TextAlignment,
  ThumbnailsAlignment,
  Type,
  VersioningMode,
  VerticalAlignment,
  ViewMode,
  ViewRole,
  VoteRole,
  WebhookIdentityType,
  Width,
  WidthType,
  bulkDeleteComment4 as bulkDeleteComment,
  bulkHideComment4 as bulkHideComment,
  bulkModerateDraftContent4 as bulkModerateDraftContent,
  bulkMoveCommentByFilter4 as bulkMoveCommentByFilter,
  bulkPublishComment4 as bulkPublishComment,
  countComments4 as countComments,
  createComment4 as createComment,
  deleteComment4 as deleteComment,
  getComment4 as getComment,
  getCommentThread4 as getCommentThread,
  hideComment4 as hideComment,
  listCommentsByResource4 as listCommentsByResource,
  markComment4 as markComment,
  moderateDraftContent4 as moderateDraftContent,
  onCommentContentChanged2 as onCommentContentChanged,
  onCommentCreated2 as onCommentCreated,
  onCommentHidden2 as onCommentHidden,
  onCommentMarked2 as onCommentMarked,
  onCommentMoved2 as onCommentMoved,
  onCommentPublished2 as onCommentPublished,
  onCommentResourceCommentCountChanged2 as onCommentResourceCommentCountChanged,
  onCommentUnmarked2 as onCommentUnmarked,
  onCommentUpdated2 as onCommentUpdated,
  publishComment4 as publishComment,
  queryComments4 as queryComments,
  unmarkComment4 as unmarkComment,
  updateComment4 as updateComment
};
//# sourceMappingURL=index.mjs.map