// src/comments-v2-comment-comments.http.ts
import { toURLSearchParams } from "@wix/sdk-runtime/rest-modules";
import { transformSDKFloatToRESTFloat } from "@wix/sdk-runtime/transformations/float";
import { transformRESTFloatToSDKFloat } from "@wix/sdk-runtime/transformations/float";
import { transformSDKTimestampToRESTTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformRESTTimestampToSDKTimestamp } from "@wix/sdk-runtime/transformations/timestamp";
import { transformPaths } from "@wix/sdk-runtime/transformations/transform-paths";
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveWixCommentsNgV1CommentsNgUrl(opts) {
  const domainToMappings = {
    "www.wixapis.com": [
      {
        srcPath: "/comments/v1/comments",
        destPath: "/v1/comments"
      },
      {
        srcPath: "/comments/v1/bulk/comments",
        destPath: "/v1/bulk/comments"
      }
    ],
    _: [
      {
        srcPath: "/_api/comments-ng/v1",
        destPath: "/v1"
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/comments-ng/v1",
        destPath: "/v1"
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/comments-ng/v1",
        destPath: "/v1"
      }
    ],
    "*.dev.wix-code.com": [
      {
        srcPath: "/_api/comments-ng",
        destPath: ""
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_comments_comments";
function createComment(payload) {
  function __createComment({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "comment.createdDate" },
          { path: "comment.updatedDate" },
          { path: "comment.commentDate" },
          { path: "comment.content.commentDate" },
          { path: "comment.content.richContent.metadata.createdTimestamp" },
          { path: "comment.content.richContent.metadata.updatedTimestamp" },
          { path: "comment.content.attachments.image.urlExpirationDate" },
          { path: "comment.content.attachments.video.urlExpirationDate" },
          {
            path: "comment.content.attachments.video.posters.urlExpirationDate"
          },
          { path: "comment.content.attachments.audio.urlExpirationDate" },
          { path: "comment.content.attachments.document.urlExpirationDate" },
          { path: "comment.draftContent.commentDate" },
          {
            path: "comment.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "comment.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "comment.draftContent.attachments.image.urlExpirationDate" },
          { path: "comment.draftContent.attachments.video.urlExpirationDate" },
          {
            path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
          },
          { path: "comment.draftContent.attachments.audio.urlExpirationDate" },
          {
            path: "comment.draftContent.attachments.document.urlExpirationDate"
          }
        ]
      },
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          {
            path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "comment.content.richContent.nodes.imageData.image.duration"
          },
          { path: "comment.content.richContent.nodes.mapData.mapSettings.lat" },
          { path: "comment.content.richContent.nodes.mapData.mapSettings.lng" },
          {
            path: "comment.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "comment.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "comment.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "comment.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.CreateComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __createComment;
}
function getComment(payload) {
  function __getComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "GET",
      methodFqn: "wix.comments.ng.v1.CommentsNg.GetComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getComment;
}
function updateComment(payload) {
  function __updateComment({ host }) {
    const serializedData = transformPaths(payload, [
      {
        transformFn: transformSDKTimestampToRESTTimestamp,
        paths: [
          { path: "comment.createdDate" },
          { path: "comment.updatedDate" },
          { path: "comment.commentDate" },
          { path: "comment.content.commentDate" },
          { path: "comment.content.richContent.metadata.createdTimestamp" },
          { path: "comment.content.richContent.metadata.updatedTimestamp" },
          { path: "comment.content.attachments.image.urlExpirationDate" },
          { path: "comment.content.attachments.video.urlExpirationDate" },
          {
            path: "comment.content.attachments.video.posters.urlExpirationDate"
          },
          { path: "comment.content.attachments.audio.urlExpirationDate" },
          { path: "comment.content.attachments.document.urlExpirationDate" },
          { path: "comment.draftContent.commentDate" },
          {
            path: "comment.draftContent.richContent.metadata.createdTimestamp"
          },
          {
            path: "comment.draftContent.richContent.metadata.updatedTimestamp"
          },
          { path: "comment.draftContent.attachments.image.urlExpirationDate" },
          { path: "comment.draftContent.attachments.video.urlExpirationDate" },
          {
            path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
          },
          { path: "comment.draftContent.attachments.audio.urlExpirationDate" },
          {
            path: "comment.draftContent.attachments.document.urlExpirationDate"
          }
        ]
      },
      {
        transformFn: transformSDKFloatToRESTFloat,
        paths: [
          {
            path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "comment.content.richContent.nodes.imageData.image.duration"
          },
          { path: "comment.content.richContent.nodes.mapData.mapSettings.lat" },
          { path: "comment.content.richContent.nodes.mapData.mapSettings.lng" },
          {
            path: "comment.content.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "comment.content.richContent.nodes.videoData.video.duration"
          },
          {
            path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "comment.content.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "comment.content.richContent.nodes.audioData.coverImage.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
          },
          {
            path: "comment.draftContent.richContent.nodes.imageData.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
          },
          {
            path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.videoData.video.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
          },
          {
            path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
          }
        ]
      }
    ]);
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PATCH",
      methodFqn: "wix.comments.ng.v1.CommentsNg.UpdateComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{comment.id}",
        data: serializedData,
        host
      }),
      data: serializedData,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __updateComment;
}
function deleteComment(payload) {
  function __deleteComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "DELETE",
      methodFqn: "wix.comments.ng.v1.CommentsNg.DeleteComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload)
    };
    return metadata;
  }
  return __deleteComment;
}
function moderateDraftContent(payload) {
  function __moderateDraftContent({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.ModerateDraftContent",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/moderate",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __moderateDraftContent;
}
function queryComments(payload) {
  function __queryComments({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.QueryComments",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/query-cursor",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comments.createdDate" },
            { path: "comments.updatedDate" },
            { path: "comments.commentDate" },
            { path: "comments.content.commentDate" },
            {
              path: "comments.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.content.richContent.metadata.updatedTimestamp"
            },
            { path: "comments.content.attachments.image.urlExpirationDate" },
            { path: "comments.content.attachments.video.urlExpirationDate" },
            {
              path: "comments.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comments.content.attachments.audio.urlExpirationDate" },
            {
              path: "comments.content.attachments.document.urlExpirationDate"
            },
            { path: "comments.draftContent.commentDate" },
            {
              path: "comments.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comments.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comments.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __queryComments;
}
function markComment(payload) {
  function __markComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.MarkComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/mark",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __markComment;
}
function unmarkComment(payload) {
  function __unmarkComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.UnmarkComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/unmark",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __unmarkComment;
}
function hideComment(payload) {
  function __hideComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.HideComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/hide",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __hideComment;
}
function publishComment(payload) {
  function __publishComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.PublishComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/publish",
        data: payload,
        host
      }),
      data: payload,
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comment.createdDate" },
            { path: "comment.updatedDate" },
            { path: "comment.commentDate" },
            { path: "comment.content.commentDate" },
            { path: "comment.content.richContent.metadata.createdTimestamp" },
            { path: "comment.content.richContent.metadata.updatedTimestamp" },
            { path: "comment.content.attachments.image.urlExpirationDate" },
            { path: "comment.content.attachments.video.urlExpirationDate" },
            {
              path: "comment.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comment.content.attachments.audio.urlExpirationDate" },
            {
              path: "comment.content.attachments.document.urlExpirationDate"
            },
            { path: "comment.draftContent.commentDate" },
            {
              path: "comment.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comment.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comment.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comment.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comment.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comment.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comment.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comment.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __publishComment;
}
function countComments(payload) {
  function __countComments({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.CountComments",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/count",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __countComments;
}
function listCommentsByResource(payload) {
  function __listCommentsByResource({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "GET",
      methodFqn: "wix.comments.ng.v1.CommentsNg.ListCommentsByResource",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/list-by-resource",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comments.createdDate" },
            { path: "comments.updatedDate" },
            { path: "comments.commentDate" },
            { path: "comments.content.commentDate" },
            {
              path: "comments.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.content.richContent.metadata.updatedTimestamp"
            },
            { path: "comments.content.attachments.image.urlExpirationDate" },
            { path: "comments.content.attachments.video.urlExpirationDate" },
            {
              path: "comments.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comments.content.attachments.audio.urlExpirationDate" },
            {
              path: "comments.content.attachments.document.urlExpirationDate"
            },
            { path: "comments.draftContent.commentDate" },
            {
              path: "comments.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comments.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.document.urlExpirationDate"
            },
            { path: "commentReplies.*.replies.createdDate" },
            { path: "commentReplies.*.replies.updatedDate" },
            { path: "commentReplies.*.replies.commentDate" },
            { path: "commentReplies.*.replies.content.commentDate" },
            {
              path: "commentReplies.*.replies.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "commentReplies.*.replies.content.richContent.metadata.updatedTimestamp"
            },
            {
              path: "commentReplies.*.replies.content.attachments.image.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.video.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.audio.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.document.urlExpirationDate"
            },
            { path: "commentReplies.*.replies.draftContent.commentDate" },
            {
              path: "commentReplies.*.replies.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comments.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __listCommentsByResource;
}
function getCommentThread(payload) {
  function __getCommentThread({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "GET",
      methodFqn: "wix.comments.ng.v1.CommentsNg.GetCommentThread",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/comments/{commentId}/thread",
        data: payload,
        host
      }),
      params: toURLSearchParams(payload),
      transformResponse: (payload2) => transformPaths(payload2, [
        {
          transformFn: transformRESTTimestampToSDKTimestamp,
          paths: [
            { path: "comments.createdDate" },
            { path: "comments.updatedDate" },
            { path: "comments.commentDate" },
            { path: "comments.content.commentDate" },
            {
              path: "comments.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.content.richContent.metadata.updatedTimestamp"
            },
            { path: "comments.content.attachments.image.urlExpirationDate" },
            { path: "comments.content.attachments.video.urlExpirationDate" },
            {
              path: "comments.content.attachments.video.posters.urlExpirationDate"
            },
            { path: "comments.content.attachments.audio.urlExpirationDate" },
            {
              path: "comments.content.attachments.document.urlExpirationDate"
            },
            { path: "comments.draftContent.commentDate" },
            {
              path: "comments.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "comments.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "comments.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "comments.draftContent.attachments.document.urlExpirationDate"
            },
            { path: "commentReplies.*.replies.createdDate" },
            { path: "commentReplies.*.replies.updatedDate" },
            { path: "commentReplies.*.replies.commentDate" },
            { path: "commentReplies.*.replies.content.commentDate" },
            {
              path: "commentReplies.*.replies.content.richContent.metadata.createdTimestamp"
            },
            {
              path: "commentReplies.*.replies.content.richContent.metadata.updatedTimestamp"
            },
            {
              path: "commentReplies.*.replies.content.attachments.image.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.video.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.audio.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.content.attachments.document.urlExpirationDate"
            },
            { path: "commentReplies.*.replies.draftContent.commentDate" },
            {
              path: "commentReplies.*.replies.draftContent.richContent.metadata.createdTimestamp"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.metadata.updatedTimestamp"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.image.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.video.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.video.posters.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.audio.urlExpirationDate"
            },
            {
              path: "commentReplies.*.replies.draftContent.attachments.document.urlExpirationDate"
            }
          ]
        },
        {
          transformFn: transformRESTFloatToSDKFloat,
          paths: [
            {
              path: "comments.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "comments.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "comments.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "comments.draftContent.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.imageData.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.videoData.video.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "commentReplies.*.replies.content.richContent.nodes.audioData.coverImage.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.image.media.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.media.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.items.video.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.galleryData.options.item.ratio"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.imageData.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lat"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.mapData.mapSettings.lng"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.poll.options.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.pollData.design.poll.background.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.appEmbedData.image.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.videoData.video.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.videoData.thumbnail.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.audioData.audio.duration"
            },
            {
              path: "commentReplies.*.replies.draftContent.richContent.nodes.audioData.coverImage.duration"
            }
          ]
        }
      ])
    };
    return metadata;
  }
  return __getCommentThread;
}
function bulkPublishComment(payload) {
  function __bulkPublishComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkPublishComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/publish-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkPublishComment;
}
function bulkHideComment(payload) {
  function __bulkHideComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkHideComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/hide-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkHideComment;
}
function bulkDeleteComment(payload) {
  function __bulkDeleteComment({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkDeleteComment",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/delete-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkDeleteComment;
}
function bulkModerateDraftContent(payload) {
  function __bulkModerateDraftContent({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "POST",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkModerateDraftContent",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/moderate-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkModerateDraftContent;
}
function bulkMoveCommentByFilter(payload) {
  function __bulkMoveCommentByFilter({ host }) {
    const metadata = {
      entityFqdn: "wix.comments.v2.comment",
      method: "PUT",
      methodFqn: "wix.comments.ng.v1.CommentsNg.BulkMoveCommentByFilter",
      packageName: PACKAGE_NAME,
      url: resolveWixCommentsNgV1CommentsNgUrl({
        protoPath: "/v1/bulk/comments/move-by-filter",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __bulkMoveCommentByFilter;
}

// src/comments-v2-comment-comments.meta.ts
function createComment2() {
  const payload = {};
  const getRequestOptions = createComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/comments",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getComment2() {
  const payload = { commentId: ":commentId" };
  const getRequestOptions = getComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/comments/{commentId}",
    pathParams: { commentId: "commentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function updateComment2() {
  const payload = { comment: { id: ":commentId" } };
  const getRequestOptions = updateComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PATCH",
    path: "/v1/comments/{comment.id}",
    pathParams: { commentId: "commentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function deleteComment2() {
  const payload = { commentId: ":commentId" };
  const getRequestOptions = deleteComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "DELETE",
    path: "/v1/comments/{commentId}",
    pathParams: { commentId: "commentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function moderateDraftContent2() {
  const payload = { commentId: ":commentId" };
  const getRequestOptions = moderateDraftContent(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/comments/{commentId}/moderate",
    pathParams: { commentId: "commentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function queryComments2() {
  const payload = {};
  const getRequestOptions = queryComments(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/comments/query-cursor",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function markComment2() {
  const payload = { commentId: ":commentId" };
  const getRequestOptions = markComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PUT",
    path: "/v1/comments/{commentId}/mark",
    pathParams: { commentId: "commentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function unmarkComment2() {
  const payload = { commentId: ":commentId" };
  const getRequestOptions = unmarkComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PUT",
    path: "/v1/comments/{commentId}/unmark",
    pathParams: { commentId: "commentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function hideComment2() {
  const payload = { commentId: ":commentId" };
  const getRequestOptions = hideComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PUT",
    path: "/v1/comments/{commentId}/hide",
    pathParams: { commentId: "commentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function publishComment2() {
  const payload = { commentId: ":commentId" };
  const getRequestOptions = publishComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PUT",
    path: "/v1/comments/{commentId}/publish",
    pathParams: { commentId: "commentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function countComments2() {
  const payload = {};
  const getRequestOptions = countComments(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/comments/count",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function listCommentsByResource2() {
  const payload = {};
  const getRequestOptions = listCommentsByResource(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/comments/list-by-resource",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function getCommentThread2() {
  const payload = { commentId: ":commentId" };
  const getRequestOptions = getCommentThread(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "GET",
    path: "/v1/comments/{commentId}/thread",
    pathParams: { commentId: "commentId" },
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkPublishComment2() {
  const payload = {};
  const getRequestOptions = bulkPublishComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/bulk/comments/publish-by-filter",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkHideComment2() {
  const payload = {};
  const getRequestOptions = bulkHideComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PUT",
    path: "/v1/bulk/comments/hide-by-filter",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkDeleteComment2() {
  const payload = {};
  const getRequestOptions = bulkDeleteComment(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PUT",
    path: "/v1/bulk/comments/delete-by-filter",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkModerateDraftContent2() {
  const payload = {};
  const getRequestOptions = bulkModerateDraftContent(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "POST",
    path: "/v1/bulk/comments/moderate-by-filter",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
function bulkMoveCommentByFilter2() {
  const payload = {};
  const getRequestOptions = bulkMoveCommentByFilter(payload);
  const getUrl = (context) => {
    const { url } = getRequestOptions(context);
    return url;
  };
  return {
    getUrl,
    httpMethod: "PUT",
    path: "/v1/bulk/comments/move-by-filter",
    pathParams: {},
    __requestType: null,
    __originalRequestType: null,
    __responseType: null,
    __originalResponseType: null
  };
}
export {
  bulkDeleteComment2 as bulkDeleteComment,
  bulkHideComment2 as bulkHideComment,
  bulkModerateDraftContent2 as bulkModerateDraftContent,
  bulkMoveCommentByFilter2 as bulkMoveCommentByFilter,
  bulkPublishComment2 as bulkPublishComment,
  countComments2 as countComments,
  createComment2 as createComment,
  deleteComment2 as deleteComment,
  getComment2 as getComment,
  getCommentThread2 as getCommentThread,
  hideComment2 as hideComment,
  listCommentsByResource2 as listCommentsByResource,
  markComment2 as markComment,
  moderateDraftContent2 as moderateDraftContent,
  publishComment2 as publishComment,
  queryComments2 as queryComments,
  unmarkComment2 as unmarkComment,
  updateComment2 as updateComment
};
//# sourceMappingURL=meta.mjs.map